Queues
======

.. py:currentmodule:: alsa_midi

.. autoclass:: Queue
   :members:

.. autoclass:: QueueInfo
   :members:

.. autoclass:: QueueStatus
   :members:

.. autoclass:: QueueTempo
   :members:

.. autoclass:: QueueTimer
   :members:

.. autoclass:: QueueTimerType
   :members:

.. py:currentmodule:: alsa_midi.queue

.. autoclass:: TimerId
   :members:
